# Changelog

## 0.1.6

- Split Usage section into subsections per function category

## 0.1.4

- Add Development section to README

## 0.1.1

- Add project URLs to pyproject.toml

## 0.1.0 (2026-03-10)

- Initial release
